<div align="center">

**Now this is podRacing!**

______________________________________________________________________

<p align="center">
  <a href="https://podracer.app">Documentation</a> •
</p>

</div>

## Installation

```sh
pip install podracer
```

### What is podRacer?

A python library for working with podcasts and RSS feeds